@@ -410,7 +410,15 @@ long Core::checker_analyze(int user, const std::string& file, bool& registered,
             return -1;
     }
     else
+    {
+        if (force_analyze)
+        {
+            db_mutex.Enter();
+            get_db()->reset_file(user, id, err);
+            db_mutex.Leave();
+        }
         registered = true;
+    }
 
     if (!analyzed && scheduler->add_element_to_queue(user, file, id, options, plugins, mil_analyze) < 0)
         return -1;
@@ -510,9 +518,9 @@ int Core::checker_status(int user, long file_id, MediaConchLib::Checker_StatusRe
         db_mutex.Enter();
         ret = get_db()->get_file_information_from_id(user, file_id, filename, file_time,
                                                res.generated_id, res.source_id, generated_time,
-                                               generated_log, generated_error_log, options, is_finished,
+                                               generated_log, generated_error_log, options, res.finished,
                                                res.has_error, res.error_log, err);
-        if (ret == 0 && is_finished)
+        if (ret == 0 && res.finished)
             ret = get_db()->get_element_report_kind(user, file_id, (MediaConchLib::report&)*res.tool, err);
         db_mutex.Leave();
     }
@@ -630,6 +638,12 @@ int Core::checker_clear(int user, const std::vector<long>& files, std::string& e
     return ret;
 }
 
+//---------------------------------------------------------------------------
+int Core::checker_stop(int user, const std::vector<long>& files, std::string& err)
+{
+    return scheduler->stop_elements(user, files, err);
+}
+
 //---------------------------------------------------------------------------
 void Core::unify_no_https(std::string& str)
 {
@@ -1391,6 +1405,15 @@ std::string Core::get_config_file()
     return config_file;
 }
 
+//---------------------------------------------------------------------------
+void Core::set_default_scheduler_max_threads(size_t nb)
+{
+    if (!scheduler)
+        return;
+        
+    scheduler->set_default_max_threads(nb);
+}
+
 //---------------------------------------------------------------------------
 void Core::set_configuration_file(const std::string& file)
 {
