@@ -408,6 +408,15 @@ int MediaConchLib::checker_clear(int user, const std::vector<long>& files, std::
     return core->checker_clear(user, files, error);
 }
 
+//---------------------------------------------------------------------------
+int MediaConchLib::checker_stop(int user, const std::vector<long>& files, std::string& error)
+{
+    if (use_daemon)
+        return daemon_client->checker_stop(user, files, error);
+
+    return core->checker_stop(user, files, error);
+}
+
 //***************************************************************************
 // Policy
 //***************************************************************************
@@ -730,6 +739,12 @@ void MediaConchLib::load_configuration()
     core->load_configuration();
 }
 
+//---------------------------------------------------------------------------
+void MediaConchLib::set_default_scheduler_max_threads(size_t nb)
+{
+    core->set_default_scheduler_max_threads(nb);
+}
+
 //---------------------------------------------------------------------------
 void MediaConchLib::set_configuration_file(const std::string& file)
 {
